@@ -420,15 +420,12 @@ bool ItemSync::eventFilter(QObject *, QEvent *event)
     return ItemWidget::filterMouseEvents(m_label, event);
 }
 
-ItemSyncSaver::ItemSyncSaver(QAbstractItemModel *model, const QString &tabPath, FileWatcher *watcher)
-    : m_model(model)
-    , m_tabPath(tabPath)
+ItemSyncSaver::ItemSyncSaver(const QString &tabPath, FileWatcher *watcher)
+    : m_tabPath(tabPath)
     , m_watcher(watcher)
 {
     if (m_watcher)
         m_watcher->setParent(this);
-    connect( model, &QAbstractItemModel::rowsMoved,
-             this, &ItemSyncSaver::onRowsMoved );
 }
 
 bool ItemSyncSaver::saveItems(const QString &tabName, const QAbstractItemModel &model, QIODevice *file)
@@ -538,44 +535,6 @@ void ItemSyncSaver::setFocus(bool focus)
         m_watcher->setUpdatesEnabled(focus);
 }
 
-void ItemSyncSaver::onRowsMoved(const QModelIndex &, int start, int end, const QModelIndex &, int destinationRow)
-{
-    if (!m_model)
-        return;
-
-    /* If own items were moved, change their base names in data to trigger
-     * updating/renaming file names so they are also moved in other app instances.
-     *
-     * The implementation works in common cases but will fail if:
-     * - Items are moved after the last own item.
-     * - Items move repeatedly to some not-top position.
-     */
-    const int count = end - start + 1;
-
-    const int baseRow = destinationRow < start
-        ? destinationRow + count
-        : destinationRow;
-    QString baseName;
-    if (destinationRow > 0) {
-        const QModelIndex baseIndex = m_model->index(baseRow, 0);
-        baseName = FileWatcher::getBaseName(baseIndex);
-
-        if ( !isOwnFile(baseName) )
-            return;
-
-        if ( !baseName.isEmpty() && !baseName.contains(QLatin1Char('-')) )
-            baseName.append(QLatin1String("-0000"));
-    }
-
-    for (int row = baseRow - 1; row >= baseRow - count; --row) {
-        const auto index = m_model->index(row, 0);
-        if ( isOwnItem(index) ) {
-            const QVariantMap data = {{mimeBaseName, baseName}};
-            m_model->setData(index, data, contentType::updateData);
-        }
-    }
-}
-
 QString ItemSyncScriptable::getMimeBaseName() const
 {
     return mimeBaseName;
@@ -819,7 +778,7 @@ ItemSaverPtr ItemSyncLoader::loadItems(const QString &tabName, QAbstractItemMode
     const auto tabPath = m_tabPaths.value(tabName);
     const auto path = files.isEmpty() ? tabPath : QFileInfo(files.first()).absolutePath();
     if ( path.isEmpty() )
-        return std::make_shared<ItemSyncSaver>(model, tabPath, nullptr);
+        return std::make_shared<ItemSyncSaver>(tabPath, nullptr);
 
     QDir dir(path);
     if ( !dir.mkpath(".") ) {
@@ -828,5 +787,5 @@ ItemSaverPtr ItemSyncLoader::loadItems(const QString &tabName, QAbstractItemMode
     }
 
     auto *watcher = new FileWatcher(path, files, model, maxItems, m_formatSettings);
-    return std::make_shared<ItemSyncSaver>(model, tabPath, watcher);
+    return std::make_shared<ItemSyncSaver>(tabPath, watcher);
 }
