@@ -266,6 +266,9 @@ void addTagButtons(QBoxLayout *layout, const ItemTags::Tags &tags)
     const QFont font = smallerFont(layout->parentWidget()->font());
 
     for (const auto &tag : tags) {
+        if ( tag.name.isEmpty() && tag.icon.isEmpty() )
+            continue;
+
         QWidget *tagWidget = new QWidget(layout->parentWidget());
         initTagWidget(tagWidget, tag, font);
         layout->addWidget(tagWidget);
@@ -908,6 +911,8 @@ void ItemTagsLoader::addTagToSettingsTable(const ItemTagsLoader::Tag &tag)
 
     auto lock = new QTableWidgetItem();
     lock->setCheckState(tag.lock ? Qt::Checked : Qt::Unchecked);
+    const QString toolTip = t->horizontalHeaderItem(tagsTableColumns::lock)->toolTip();
+    lock->setToolTip(toolTip);
     t->setItem( row, tagsTableColumns::lock, lock );
 
     auto colorButton = new QPushButton(t);
