@@ -53,6 +53,7 @@ const int maxLineCountInPreview = 16 * maxLineCount;
 const QLatin1String optionUseRichText("use_rich_text");
 const QLatin1String optionMaximumLines("max_lines");
 const QLatin1String optionMaximumHeight("max_height");
+const QLatin1String optionDefaultStyleSheet("default_style_sheet");
 
 // Some applications insert \0 teminator at the end of text data.
 // It needs to be removed because QTextBrowser can render the character.
@@ -88,7 +89,14 @@ void insertEllipsis(QTextCursor *tc)
 
 } // namespace
 
-ItemText::ItemText(const QString &text, const QString &richText, int maxLines, int lineLength, int maximumHeight, QWidget *parent)
+ItemText::ItemText(
+        const QString &text,
+        const QString &richText,
+        const QString &defaultStyleSheet,
+        int maxLines,
+        int lineLength,
+        int maximumHeight,
+        QWidget *parent)
     : QTextEdit(parent)
     , ItemWidget(this)
     , m_textDocument()
@@ -100,6 +108,7 @@ ItemText::ItemText(const QString &text, const QString &richText, int maxLines, i
     QTextOption option = m_textDocument.defaultTextOption();
     option.setWrapMode(QTextOption::NoWrap);
     m_textDocument.setDefaultTextOption(option);
+    m_textDocument.setDefaultStyleSheet(defaultStyleSheet);
 
     setReadOnly(true);
     setUndoRedoEnabled(false);
@@ -251,7 +260,7 @@ ItemWidget *ItemTextLoader::create(const QVariantMap &data, QWidget *parent, boo
     Qt::TextInteractionFlags interactionFlags(Qt::LinksAccessibleByMouse);
     // Always limit text size for performance reasons.
     if (preview) {
-        item = new ItemText(text, richText, maxLineCountInPreview, maxLineLengthInPreview, -1, parent);
+        item = new ItemText(text, richText, m_defaultStyleSheet, maxLineCountInPreview, maxLineLengthInPreview, -1, parent);
         item->setFocusPolicy(Qt::StrongFocus);
         interactionFlags = interactionFlags
                 | Qt::TextSelectableByKeyboard
@@ -260,7 +269,7 @@ ItemWidget *ItemTextLoader::create(const QVariantMap &data, QWidget *parent, boo
         int maxLines = m_maxLines;
         if (maxLines <= 0 || maxLines > maxLineCount)
             maxLines = maxLineCount;
-        item = new ItemText(text, richText, maxLines, maxLineLength, m_maxHeight, parent);
+        item = new ItemText(text, richText, m_defaultStyleSheet, maxLines, maxLineLength, m_maxHeight, parent);
         item->viewport()->installEventFilter(item);
         item->setContextMenuPolicy(Qt::NoContextMenu);
     }
@@ -281,6 +290,7 @@ void ItemTextLoader::applySettings(QSettings &settings)
     settings.setValue(optionUseRichText, ui->checkBoxUseRichText->isChecked());
     settings.setValue(optionMaximumLines, ui->spinBoxMaxLines->value());
     settings.setValue(optionMaximumHeight, ui->spinBoxMaxHeight->value());
+    settings.setValue(optionDefaultStyleSheet, ui->textEditDefaultStyleSheet->toPlainText());
 }
 
 void ItemTextLoader::loadSettings(const QSettings &settings)
@@ -288,6 +298,7 @@ void ItemTextLoader::loadSettings(const QSettings &settings)
     m_useRichText = settings.value(optionUseRichText, true).toBool();
     m_maxLines = settings.value(optionMaximumLines, maxLineCount).toInt();
     m_maxHeight = settings.value(optionMaximumHeight).toInt();
+    m_defaultStyleSheet = settings.value(optionDefaultStyleSheet).toString();
 }
 
 QWidget *ItemTextLoader::createSettingsWidget(QWidget *parent)
@@ -298,5 +309,6 @@ QWidget *ItemTextLoader::createSettingsWidget(QWidget *parent)
     ui->checkBoxUseRichText->setChecked(m_useRichText);
     ui->spinBoxMaxLines->setValue(m_maxLines);
     ui->spinBoxMaxHeight->setValue(m_maxHeight);
+    ui->textEditDefaultStyleSheet->setPlainText(m_defaultStyleSheet);
     return w;
 }
