@@ -22,6 +22,7 @@
 
 #include <errno.h>
 #include <poll.h>
+#include <signal.h>
 #include <string.h>
 #include <unistd.h>
 
@@ -75,8 +76,21 @@ protected:
     void run() override {
         QFile c;
         if (c.open(m_fd, QFile::WriteOnly, QFile::AutoCloseHandle)) {
-            c.write(m_data);
+            // Create a sigpipe handler that does nothing, or clients may be forced to terminate
+            // if the pipe is closed in the other end.
+            struct sigaction action, oldAction;
+            action.sa_handler = SIG_IGN;
+            sigemptyset(&action.sa_mask);
+            action.sa_flags = 0;
+            sigaction(SIGPIPE, &action, &oldAction);
+            const qint64 written = c.write(m_data);
+            sigaction(SIGPIPE, &oldAction, nullptr);
             c.close();
+
+            if (written != m_data.size()) {
+                qWarning() << "Failed to send all clipobard data; sent"
+                           << written << "bytes out of" << m_data.size();
+            }
         }
     }
 
