@@ -155,6 +155,8 @@ private slots:
     void classTemporaryFile();
     void classItemSelection();
     void classItemSelectionGetCurrent();
+    void classItemSelectionByteArray();
+    void classSettings();
     void calledWithInstance();
 
     void pipingCommands();
